Opinions & Announcements Search
Description: Opinion Site
Keywords: Decisions, Opinions, Files, Documents, Reporter

# The Supreme Court of Ohio & The Ohio Judicial System

## Opinions & Announcements
Source: |
Decided: |
WebCite No: |
Full Text: |
Enter either a webcite number or a full text query.
Columns to Include
Case Name Case No Topics/Issues | Author County Citation | Decided Date Posted Date WebCite
Notices
Supreme Court opinions and Supreme Court announcements are usually posted weekdays at 9:00 a.m. Other documents are posted as received by the court.
All documents are in the Adobe® PDF format. The Adobe® Reader® is a free download. |
| Rows per Page

58 documents were found matching the selected criteria.

Case Name | Case No. | Topics and Issues | Author | Decided | WebCite
--- | --- | --- | --- | --- | ---
Remillard v. Ohio State Hwy. Patrol | 2012-08630-AD | Property damage, canine unit. Burden of proof, duty of care. Judgment for defendant. | Borchert | 11/15/2013 | 2013-Ohio-5922
Warth v. Ohio State Hwy. Patrol | 2013-00031-AD | Property damage. OSHP officer caused damage with flashlight. Defendant immune from liability since acting at the time of an emergency. Judgment for defendant. | Borchert | 10/30/2013 | 2013-Ohio-5924
Mason v. Ohio Dept. of Rehab. & Corr. | 2012-08753-AD | Inmate property loss. Bailment. Burden of proof, duty of care. Judgment for plaintiff. | Borchert | 10/30/2013 | 2013-Ohio-5923
Sommer v. Ohio Dept. of Transp. | 2012-04715 | Judgment entry. Defendant’s motion for summary judgment is granted and judgment rendered in favor of defendant. | McGrath | 8/30/2013 | 2013-Ohio-5943
Evert v. Ohio State Univ. | 2012-03719 | Magistrate decision. Magistrate recommends judgment in favor of defendant. | Van Schoyck | 8/30/2013 | 2013-Ohio-5942
Kara v. Ohio Dept. of Taxation | 2012-03794 | Decision and judgment entry. Defendant’s motion for summary judgment granted in part and denied in part. | McGrath | 8/26/2013 | 2013-Ohio-5944
Dalton v. Ohio Dept. of Rehab. & Corr. | 2012-01457 | Decision and judgment entry. Defendant’s motion for summary judgment granted and judgment rendered in favor of defendant. | McGrath | 8/26/2013 | 2013-Ohio-5941
Gilmore v. Ohio Dept. of Transp. | 2012-002569 | Decision and judgment entry. Judgment rendered in favor of defendant. | McGrath | 8/26/2013 | 2013-Ohio-5940
Wrinn v. Ohio State Hwy. Patrol | 2006-05934 | Judgment entry. Sergeant Daren Johnson is not entitled to immunity pursuant to R.C. 9.86 and 2743.02(F). | McGrath | 8/16/2013 | 2013-Ohio-5939
Austin v. Miami Univ. | 2013-00078-AD | Personal injury. Struck by hockey puck. Assumption of the risk. Burden of proof, duty of care. Judgment for defendant. | Borchert | 8/13/2013 | 2013-Ohio-5925
McClair v. Univ. of Toledo | 2012-04961 | Decision and judgment entry. Defendant’s motion for summary judgment granted and judgment rendered in favor of defendant. | McGrath | 8/7/2013 | 2013-Ohio-5938
Somasundaram v. Kent State Univ. | 2012-04197 | Judgment entry. Defendant’s motion for summary judgment is granted and judgment rendered in favor of defendant. | McGrath | 8/7/2013 | 2013-Ohio-5937
Cristino v. Ohio Bur. of Workers' Comp. | 2008-10773 | Judgment entry. Defendant’s motion for summary judgment granted and judgment rendered in favor of defendant. | McGrath | 8/2/2013 | 2013-Ohio-5936
Premier Med. Mgt., Inc. v. Bur. of Workers' Comp. | 2012-07358 | Judgment entry. Defendant’s motion for summary judgment granted and judgment rendered in favor of defendant. | McGrath | 8/2/2013 | 2013-Ohio-5935
Casteel v. Univ. of Akron | 2011-12188 | Decision and judgment entry. Judgment rendered in favor of defendants. | McGrath | 7/25/2013 | 2013-Ohio-5934
Vokoun v. Cleveland State Univ. | 2012-06581-AD | Parking gate. Personal injury. Invitee to trespasser. Signage. Burden of proof, duty of care. Judgment for defendant. | Borchert | 7/23/2013 | 2013-Ohio-5920
Kelm v. Ohio Dept. of Transp. | 2011-09411 | Judgment entry. Defendants’ motion for summary judgment granted and judgment rendered in favor of defendants. | McGrath | 7/19/2013 | 2013-Ohio-5933
Painter v. Ohio State Univ. Med. Ctr. | 2011-12307 | Magistrate decision. Magistrate recommends judgment in favor of defendant. | Van Schoyck | 7/19/2013 | 2013-Ohio-5932
West-Kimmons v. Univ. of Toledo Med. Ctr. | 2011-12927 | Judgment entry. Defendant’s motion for summary judgment is granted and judgment rendered in favor of defendant. | McGrath | 7/18/2013 | 2013-Ohio-5931
Mlakar v. Miami Univ. | 2012-01791 | Magistrate decision. Magistrate recommends judgment in favor of defendant. | Shaver | 7/11/2013 | 2013-Ohio-5930
Randolph v. Terra State Community College | 2012-04421 | Decision and judgment entry. Defendant’s motion for summary judgment granted and judgment rendered in favor of defendant. | Crawford | 7/11/2013 | 2013-Ohio-5929
Savoy v. Univ. of Akron | 2010-11285 | Judgment entry. Defendant’s motion for summary judgment is granted and judgment rendered in favor of defendant. | McGrath | 7/10/2013 | 2013-Ohio-5928
Savage v. Ohio State Univ. | 2009-06575 | Magistrate decision. Magistrate recommends judgment in favor of defendant. | Shaver | 6/25/2013 | 2013-Ohio-4856
Kuhbanani v. Ohio State Univ. Med. Ctr. | 2011-08547 | Magistrate Decision. Magistrate recommends that Dr. Sarah Artman is not entitled to immunity pursuant to R.C. 9.86 and 2743.02(F). | Renick | 6/21/2013 | 2013-Ohio-4855
Hale v. Ohio Dept. of Adm. Servs. | 2012-03484 | Decision and judgment entry. Defendants’ motion for summary judgment granted and judgment rendered in favor of defendants. | Cosgrove | 6/19/2013 | 2013-Ohio-4854
Hines v. Univ. of Akron | 2011-11009 | Judgment entry. Defendant’s motion for summary judgment granted and judgment rendered in favor of defendant. | McGrath | 6/7/2013 | 2013-Ohio-4853
Schneider v. Univ. of Cincinnati | 2012-04642 | Judgment entry. Plaintiff’s objections overruled, magistrate’s decision adopted. Dr. Diya Mutasim is entitled to immunity pursuant to R.C. 9.86 and R.C. 2743.02(F). Plaintiff’s case dismissed. | McGrath | 6/6/2013 | 2013-Ohio-4852
Alsup v. Univ. of Cincinnati | 2010-04602 | Magistrate Decision. Magistrate recommends judgment in favor of plaintiff in the amount of $35,025. | Renick | 6/3/2013 | 2013-Ohio-4850
Flores v. Bowling Green State Univ. | 2012-07153 | Judgment entry. Defendant’s motion for summary judgment granted and judgment rendered in favor of defendant. | McGrath | 5/28/2013 | 2013-Ohio-4864
Wittensoldner v. Ohio Dept. of Transp. | 2011-05823 | Judgment entry. Defendant’s motion for summary judgment granted and judgment rendered in favor of defendant. | McGrath | 5/28/2013 | 2013-Ohio-4863
Kinnison v. Ohio State Univ. | 2011-08644 | Decision and judgment entry. Defendant’s motion for summary judgment granted and judgment rendered in favor of defendants. | McGrath | 5/24/2013 | 2013-Ohio-4862
Strickling v. Ohio State Hwy. Patrol | 2012-06050 | Judgment entry. Defendant’s motion for summary judgment granted and judgment rendered in favor of defendant. | McGrath | 5/15/2013 | 2013-Ohio-4840
Swartz v. Univ. of Toledo Med. Ctr. | 2011-07761 | Judgment entry. Defendant’s and plaintiffs’ objections overruled, magistrate’s recommendation adopted, and judgment entered in favor of plaintiffs in the amount of $400,878.88. | McGrath | 5/6/2013 | 2013-Ohio-4839
Lee v. Ohio Dept. of Transp. | 2012-08338-AD | Automobile damage. Defendant's agent violated assured clear distance law. Burden of proof, duty of care. Judgment for plaintiff. | Borchert | 4/29/2013 | 2013-Ohio-5921
Jess Howard Electric Co. v. Ohio School Facilities Comm. | 2010-12737 | Decision and judgment entry. Judgment rendered in favor of defendant. | Weaver | 4/26/2013 | 2013-Ohio-3642
Keegan v. Univ. of Toledo College of Medicine | 2012-04413 | Magistrate decision. Magistrate recommends a determination that Dr. Daniel J. Kosinski is entitled to civil immunity pursuant to R.C. 9.86 and 2743.02(F). | Van Schoyck | 4/24/2013 | 2013-Ohio-3641
Pallone v. Ohio Dept. of Natural Resources | 2010-10505 | Judgment entry. Plaintiff’s objections to the magistrate’s decision were overruled, and the magistrate’s decision and recommendation was adopted by the court. Judgment rendered in favor of defendant. | McGrath | 4/12/2013 | 2013-Ohio-3640
Rex v. Univ. of Cincinnati College of Medicine | 2009-04637 | Judgment entry. Plaintiffs objections overruled, magistrate’s recommendation adopted, and judgment entered in favor of defendant. | McGrath | 4/12/2013 | 2013-Ohio-3638
Haas v. Univ. of Toledo Med. Ctr. | 2010-11005 | Judgment entry. Defendant’s motion for summary judgment is granted and judgment rendered in favor of defendant. | McGrath | 4/12/2013 | 2013-Ohio-3636
Swartz v. Univ. of Toledo Med. Ctr. | 2011-07761 | Magistrate decision. Magistrate recommends judgment in favor of plaintiffs in the amount of $400,878.88. | Renick | 4/6/2013 | 2013-Ohio-1516
Thompson v. Ohio Univ. | 2011-07354-AD | Automobile damage, smoke stack related damage. Burden of proof, duty of care. Expert opinions. Judgment for defendant. | Borchert | 4/4/2013 | 2013-Ohio-5917
Miller v. Ohio Dept. of Transp. | 2009-07679 | Decision and judgment entry. Judgment rendered in favor of plaintiff in the amount of $3,343,025. | McGrath | 4/4/2013 | 2013-Ohio-3635
Willoby v. Ohio Dept. of Transp. | 2009-03037 | Judgment entry. Defendants’ motion for summary judgment is granted and judgment rendered in favor of defendants. | McGrath | 4/1/2013 | 2013-Ohio-3633
Kasotis v. Ohio Dept. of Transp. | 2009-03045 | Judgment entry. Defendants’ motion for summary judgment is granted and judgment rendered in favor of defendants. | McGrath | 4/1/2013 | 2013-Ohio-3632
Moscato v. Ohio State Univ. | 2011-06552 | Magistrate decision. Magistrate recommends judgment in favor of plaintiff. | Renick | 3/27/2013 | 2013-Ohio-3631
Rosenshine v. Med. College Hosp. | 98-04701 | Judgment entry. Defendant’s objections to the magistrate’s decision were overruled, and the magistrate’s decision and recommendation was modified, in part. Judgment rendered in favor of plaintiff in the amount of $210,743.57. | McGrath | 3/15/2013 | 2013-Ohio-3630
Miller v. Ohio Dept. of Rehab. & Corr. | 2011-13141 | Magistrate decision. Magistrate recommends judgment in favor of defendant. | Shaver | 3/8/2013 | 2013-Ohio-3629
Leone v. Ohio Lottery Comm. | 2010-12338 | Decision and judgment entry. Judgment rendered in favor of defendant. | Weaver | 3/7/2013 | 2013-Ohio-3628
Smith v. N. Ohio Med. Univ. | 2012-06017-AD | Personal injury. Bone and gristle in sandwich natural occurrence. Burden of proof, duty of care. Judgment for defendant. | Borchert | 2/28/2013 | 2013-Ohio-5919
Univ. of Toledo Chapter of Am. Assn. of Univ. Professors v. Univ. of Toledo | 2012-01783 | Judgment entry. Defendant’s motion for summary judgment granted and judgment rendered in favor of defendant. | McGrath | 2/7/2013 | 2013-Ohio-1517
Reed v. Ohio Dept. of Transp. | 2010-02065 | Decision and judgment entry. Judgment rendered in favor of plaintiff in the amount of $4,364,735. | Travis | 2/4/2013 | 2013-Ohio-1515
Daugherty v. Ohio Dept. of Transp. | 2012-04031-AD | Real property damage. Construction of catch basin and related piping. Burden of proof, duty of care. Judgment for defendant. | Borchert | 1/30/2013 | 2013-Ohio-5918
Pallone v. Ohio Dept. of Natural Resources | 2010-10505 | Magistrate decision. Magistrate recommends judgment in favor of defendant. | Renick | 1/30/2013 | 2013-Ohio-3639
Rex v. Univ. of Cincinnati College of Medicine | 2009-04637 | Magistrate decision. Magistrate recommends judgment in favor of defendant. | Renick | 1/26/2013 | 2013-Ohio-1514
Rex v. Univ. of Cincinnati College of Medicine | 2009-04637 | Magistrate decision. Magistrate recommends judgment in favor of defendant. | Renick | 1/25/2013 | 2013-Ohio-3637
Morgan v. Ohio State Univ. College of Dentistry | 2010-05111 | Decision and judgment entry. Judgment rendered in favor of defendant. Dr. Julie Holloway is entitled to immunity pursuant to R.C. 9.86 and 2743.02(F). | Crawford | 1/18/2013 | 2013-Ohio-1513
Warden v. Ohio Dept. of Natural Resources | 2011-01232 | Decision and judgment entry. Judgment rendered in favor of plaintiff in the amount of $507,656.75. | Travis | 1/15/2013 | 2013-Ohio-1512
Conner v. Wright State Univ. | 2012-02887 | Decision and judgment entry. Defendants’ motion for summary judgment granted and judgment rendered in favor of defendants. | McGrath | 1/8/2013 | 2013-Ohio-1511

Page: